# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We don't really need ExtUtils::MakeMaker ≥ 6.30
%global old_eumm %(perl -MExtUtils::MakeMaker -e 'print (($ExtUtils::MakeMaker::VERSION < 6.30) ? 1 : 0);' 2>/dev/null || echo 0)

# We'll not ship the manpage for Fatal.pm for 5.8 as it'll conflict with the legacy one in the main perl package
%global ship_fatal_manpage %(perl -e 'print $] >= 5.009 ? 1 : 0;')

Name:		perl-autodie
Version:	2.23
Release:	1.%{__distinit}%{__distvers}
Summary:	Replace functions with ones that succeed or die
Group:		Development/Libraries
License:	GPL+ or Artistic
URL:		http://search.cpan.org/dist/autodie/
Source0:	http://search.cpan.org/CPAN/authors/id/P/PJ/PJF/autodie-%{version}.tar.gz
Patch0:		autodie-2.23-old-eu::mm.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
BuildRequires:	perl >= 3:5.8.4
BuildRequires:	perl(base)
BuildRequires:	perl(BSD::Resource)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Config)
BuildRequires:	perl(constant)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.17
BuildRequires:	perl(File::Copy)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(if)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IPC::System::Simple) >= 0.12
BuildRequires:	perl(lib)
BuildRequires:	perl(parent)
BuildRequires:	perl(Socket)
BuildRequires:	perl(Sub::Identify)
# perl-Test-Kwalitee -> perl-Test-CleanNamespaces -> perl-Moose -> perl-Module-Refresh
#		-> perl-Path-Class -> perl-Test-Perl-Critic -> perl-Perl-Critic -> perl-autodie
# Old Test::Kwalitee on 5.8 uses bogus metric, which this package fails on
%if 0%{!?perl_bootstrap:1} && %(perl -e 'print $] >= 5.009 ? 1 : 0;')
BuildRequires:	perl(Test::Kwalitee) >= 1.12
%endif
BuildRequires:	perl(Test::More)
# perl-Test-Perl-Critic -> perl-Perl-Critic-> perl-autodie
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(Test::Perl::Critic)
%endif
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
BuildRequires:	perl(Tie::RefHash)
# This conflicts because there's a naked subroutine (DOES)
# found in the release pod coverage test, at least in autodie 2.23
BuildConflicts:	perl(Pod::Coverage::TrustPod)
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
Requires:	perl(IPC::System::Simple) >= 0.12

%description
The autodie pragma has lexical scope, meaning that functions and subroutines
altered with autodie will only change their behavior until the end of the
enclosing block, file, or eval.

If system is specified as an argument to autodie, then it uses
IPC::System::Simple to do the heavy lifting.

%prep
%setup -q -n autodie-%{version}

# We don't really need ExtUtils::MakeMaker ≥ 6.30
%if %{old_eumm}
%patch0
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} \;
%{_fixperms} %{buildroot}

%check
make test AUTHOR_TESTING=1 RELEASE_TESTING=1

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc AUTHORS Changes LICENSE README
%{perl_vendorlib}/Fatal.pm
%{perl_vendorlib}/autodie.pm
%{perl_vendorlib}/autodie/
%{_mandir}/man3/autodie.3pm*
%{_mandir}/man3/autodie::exception.3pm*
%{_mandir}/man3/autodie::exception::system.3pm*
%{_mandir}/man3/autodie::hints.3pm*
%{_mandir}/man3/autodie::skip.3pm*
%if %{ship_fatal_manpage}
%{_mandir}/man3/Fatal.3pm*
%else
%exclude %{_mandir}/man3/Fatal.3pm*
%endif

%changelog
* Mon Jan 27 2014 Paul Howarth <paul@city-fan.org> - 2.23-1
- Update to 2.23
  - TEST/BUGFIX: Improved testing support on Android and Blackberry devices
    (GH #44)
  - TEST/INTERNAL/TRAVIS: Various non-code tweaks to make travis-ci more happy
    with testing autodie
  - BUGFIX: autodie no longer weakens strict by allowing undeclared variables
    with the same name as built-ins (CPAN RT#74246)
  - BUGFIX: `use autodie qw( foo ! foo);` now correctly insists that we have
    hints for foo
  - INTERNAL: Improved benchmarking code
- Update patch to support building with ExtUtils::MakeMaker < 6.30

* Sat Sep 21 2013 Paul Howarth <paul@city-fan.org> - 2.22-1
- Update to 2.22
  - TEST/INTERNAL: Restore timestamps on touched testing files to avoid git
    flagging files having changed in git (CPAN RT#88444)

* Thu Sep 12 2013 Paul Howarth <paul@city-fan.org> - 2.21-1
- Update to 2.21
  - SPEED/INTERNAL: Through the magic of globally reuseable core leak
    trampolines, autodie is even faster when used across multiple packages
  - SPEED/INTERNAL: Caches used for keeping track of fatalised subroutines are
    faster and leaner
  - SPEED/INTERNAL: Core subroutine wrappers are now lazily compiled
  - SPEED/INTERNAL: Using autodie while autodie is already in effect is now
    faster and more efficient
  - INTERNAL: $" and $! are no longer arbitrarily messed with for no reason via
    autodie (they're still messed with when using Fatal)
  - SPEED/INTERNAL: The ':all' tag hierachy is expanded immediately, in an
    efficient fashion
  - INTERNAL: Numerous minor clean-ups, dead variables removed, typos fixed
  - SPEED/INTERNAL: import() and _make_fatal() cache more aggressively,
    reducing CPU overhead
  - TEST: Compatibility with Carp 1.32 (CPAN RT#88076)
- Don't run the Kwalitee test on 5.8.x

* Sun Sep  1 2013 Paul Howarth <paul@city-fan.org> - 2.20-4
- Don't ship the manpage for Fatal.pm for 5.8 as it'll conflict with the legacy
  one in the main perl package

* Fri Jul 19 2013 Paul Howarth <paul@city-fan.org> - 2.20-3
- Perl 5.18 rebuild

* Fri Jul  5 2013 Paul Howarth <paul@city-fan.org> - 2.20-2
- BR: perl(ExtUtils::MakeMaker)
- Don't run Critic or Kwalitee tests when bootstrapping

* Mon Jun 24 2013 Paul Howarth <paul@city-fan.org> - 2.20-1
- Update to 2.20
  - SPEED/INTERNAL: Less time is spent computing prototypes
  - SPEED/INTERNAL: Leak guards are more efficient
  - SPEED: Expanding tags (eg: qw(:all)) is now faster; this also improves the
    speed of checking autodying code with Perl::Critic
  - INTERNAL: Expanding of tags is faster and preserves order

* Mon May 13 2013 Paul Howarth <paul@city-fan.org> - 2.19-1
- Update to 2.19
  - BUGFIX: Loading a file that does not change packages while autodie in
    effect no longer causes weird behaviour when slurpy built-ins (like open()
    and unlink()) are called (GH #22)
  - TEST: More testing in scope_leak.t
  - TEST: More testing around packages in truncate.t
  - TEST: Tests for leak guard failures for slurpy core functions
  - SPEED/INTERNAL: Significant improvements in load time, especially when
    autodie is used across multiple files, by caching reuseable subroutines
    and reducing calls to eval "" (CPAN RT#46984)
  - DOCUMENTATION: Spelling and correction fixes
  - DEVEL: Faster and more robust testing with travis-ci
  - DEVEL: Some simple benchmarks bundled in the benchmarks/ directory

* Sun Apr 28 2013 Paul Howarth <paul@city-fan.org> - 2.17-1
- Update to 2.17
  - Spelling fixes thanks to dsteinbrunner! (CPAN RT#84897)
  - Fixed github links to point to 'pjf' rather than 'pfenwick' (GH #18)
  - Silence warnings about experimental smart-match on 5.17.11+
  - Generate .travis.yml files for CI testing via dzil

* Fri Feb 22 2013 Paul Howarth <paul@city-fan.org> - 2.16-1
- Update to 2.16
  - Classes that claim they ->DOES('autodie::skip') are now skipped when
    generating exceptions; this is mainly of use to utility classes - see
    'perldoc autodie::skip' for more details (GH Issue #15)
  - 'chmod' is now in the ':filesys' category (was in ':file')
  - Added support for 'chown' and 'utime', which was previously overlooked;
    these are all in the ':filesys' category (GH Pull #13)
  - Added support for 'kill' (this is part of the ':ipc' category)
  - Fixed bug whereby chmod, chown, kill, unlink and utime would not throw an
    exception when they didn't change all their files or signal all their
    processes
  - truncate.t is now skipped on systems that don't have a working File::Temp
  - open.t has a few more tests for exotic modes
  - chown() tests are skipped on Win32, as chown on Windows is a no-op
  - Author tests now look for the AUTHOR_TESTING env variable (for dzil
    compliance)
  - Better testing for chown, chmod, ulink and unlink
  - kwalitee.t is now only run when $ENV{RELEASE_TESTING} is set
  - Removed executable bits from some bundled text files
  - We now use dzil to manage autodie
  - Only Perl 5.8.4 and above is supported by autodie
- New manpage for autodie::skip
- Upstream dropped TODO, added LICENSE
- No longer need to fix permissions in %%prep
- Drop BR: perl(Cwd), no longer needed as Module::Install dropped
- BR: perl ≥ 3:5.8.4 as per upstream
- BR: perl(Exporter), perl(File::Copy), perl(File::Spec), perl(File::Temp),
  perl(IO::Handle), perl(parent) and perl(Socket)
- Specify version requirements for Test::Pod and Test::Pod::Coverage
- Add BuildConflict for perl(Pod::Coverage::TrustPod) because there's a naked
  subroutine found in the release pod coverage test
- Add patch to support building with ExtUtils::MakeMaker < 6.30

* Thu Nov  8 2012 Paul Howarth <paul@city-fan.org> - 2.13-1
- Update to 2.13
  - Deterministic tests in hints_pod_examples.t (CPAN RT#80412)
  - Subroutine installs are now done in a deterministic order (CPAN RT#80414)

* Wed Jun 27 2012 Paul Howarth <paul@city-fan.org> - 2.12-1
- Update to 2.12
  - autodie now plays nicely with the 'open' pragma (CPAN RT#54777)
  - Updated to Module::Install 1.06
  - Makefile.PL is less redundant
  - t/pod-coverage.t no longer thinks LEXICAL_TAG is a user-visible subroutine

* Fri Mar 23 2012 Paul Howarth <paul@city-fan.org> - 2.11-1
- Update to 2.11
  - Explicitly documented that autodie is context-unaware
  - Multi-arg open tests are skipped on VMS
  - Bugfix: recv.t shouldn't assume STDIN is a file handle
  - Fixed compatibility with Carp 1.25
  - Exception classes are loaded more safely
- Add buildreqs for Perl core modules that could be dual-lived
- BR: perl(Test::Pod::Coverage) now that coverage test passes
- Don't need to remove empty directories from buildroot
- Drop compatibility with distributions prior to FC-3:
  - Drop patch for CPAN RT#53506
  - Don't need to define %%{perl_vendorlib}
  - BR: perl(Test::Perl::Critic) unconditionally
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Mon Oct 17 2011 Paul Howarth <paul@city-fan.org> - 2.10-4
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Mar 23 2011 Paul Howarth <paul@city-fan.org> - 2.10-3
- Unconditionally BR: perl(Test::Kwalitee)
- Nobody else likes macros for commands

* Tue Mar 22 2011 Paul Howarth <paul@city-fan.org> - 2.10-2
- BR: perl(Test::Kwalitee)

* Tue Feb  8 2011 Paul Howarth <paul@city-fan.org> - 2.10-1
- Initial RPM version
